@@ -206,6 +206,11 @@ void QgsInstancedPoint3DSymbolHandler::finalize( Qt3DCore::QEntity *parent, cons
 
 void QgsInstancedPoint3DSymbolHandler::makeEntity( Qt3DCore::QEntity *parent, const Qgs3DRenderContext &context, PointData &out, bool selected )
 {
+  if ( out.positions.isEmpty() )
+  {
+    return; // nothing to show - no need to create the entity
+  }
+
   // build the default material
   QgsMaterialContext materialContext;
   materialContext.setIsSelected( selected );
@@ -249,8 +254,15 @@ QgsMaterial *QgsInstancedPoint3DSymbolHandler::material( const QgsPoint3DSymbol
   technique->graphicsApiFilter()->setMajorVersion( 3 );
   technique->graphicsApiFilter()->setMinorVersion( 2 );
 
-  const QMatrix4x4 transformMatrix = symbol->transform();
-  QMatrix3x3 normalMatrix = transformMatrix.normalMatrix(); // transponed inverse of 3x3 sub-matrix
+  const QMatrix4x4 tempTransformMatrix = symbol->transform();
+  // our built-in 3D geometries (e.g. cylinder, plane, ...) assume Y axis going "up",
+  // let's rotate them by default so that their Z axis goes "up" (like the rest of the scene)
+  QMatrix4x4 id;
+  id.rotate( QQuaternion::fromAxisAndAngle( QVector3D( 1, 0, 0 ), 90 ) );
+  const QMatrix4x4 transformMatrix = tempTransformMatrix * id;
+
+  // transponed inverse of 3x3 sub-matrix
+  QMatrix3x3 normalMatrix = transformMatrix.normalMatrix();
 
   // QMatrix3x3 is not supported for passing to shaders, so we pass QMatrix4x4
   float *n = normalMatrix.data();
@@ -478,6 +490,11 @@ void QgsModelPoint3DSymbolHandler::finalize( Qt3DCore::QEntity *parent, const Qg
 
 void QgsModelPoint3DSymbolHandler::makeEntity( Qt3DCore::QEntity *parent, const Qgs3DRenderContext &context, PointData &out, bool selected )
 {
+  if ( out.positions.isEmpty() )
+  {
+    return; // nothing to show - no need to create the entity
+  }
+
   if ( selected )
   {
     addMeshEntities( context, out.positions, mChunkOrigin, mSymbol.get(), parent, true );
@@ -501,11 +518,11 @@ void QgsModelPoint3DSymbolHandler::makeEntity( Qt3DCore::QEntity *parent, const
 void QgsModelPoint3DSymbolHandler::addSceneEntities( const Qgs3DRenderContext &context, const QVector<QVector3D> &positions, const QgsVector3D &chunkOrigin, const QgsPoint3DSymbol *symbol, Qt3DCore::QEntity *parent )
 {
   Q_UNUSED( context );
-  for ( const QVector3D &position : positions )
+  const QString source = QgsApplication::sourceCache()->localFilePath( symbol->shapeProperty( QStringLiteral( "model" ) ).toString() );
+  // if the source is remote, the Qgs3DMapScene will take care of refreshing this 3D symbol when the source is fetched
+  if ( !source.isEmpty() )
   {
-    const QString source = QgsApplication::sourceCache()->localFilePath( symbol->shapeProperty( QStringLiteral( "model" ) ).toString() );
-    // if the source is remote, the Qgs3DMapScene will take care of refreshing this 3D symbol when the source is fetched
-    if ( !source.isEmpty() )
+    for ( const QVector3D &position : positions )
     {
       // build the entity
       Qt3DCore::QEntity *entity = new Qt3DCore::QEntity;
@@ -522,6 +539,10 @@ void QgsModelPoint3DSymbolHandler::addSceneEntities( const Qgs3DRenderContext &c
       // cppcheck-suppress memleak
     }
   }
+  else
+  {
+    QgsDebugMsgLevel( QStringLiteral( "File '%1' is not accessible!" ).arg( symbol->shapeProperty( QStringLiteral( "model" ) ).toString() ), 1 );
+  }
 }
 
 void QgsModelPoint3DSymbolHandler::addMeshEntities( const Qgs3DRenderContext &context, const QVector<QVector3D> &positions, const QgsVector3D &chunkOrigin, const QgsPoint3DSymbol *symbol, Qt3DCore::QEntity *parent, bool are_selected )
@@ -529,22 +550,23 @@ void QgsModelPoint3DSymbolHandler::addMeshEntities( const Qgs3DRenderContext &co
   if ( positions.empty() )
     return;
 
-  // build the default material
-  QgsMaterialContext materialContext;
-  materialContext.setIsSelected( are_selected );
-  materialContext.setSelectionColor( context.selectionColor() );
-  QgsMaterial *mat = symbol->materialSettings()->toMaterial( QgsMaterialSettingsRenderingTechnique::Triangles, materialContext );
-
-  // get nodes
-  for ( const QVector3D &position : positions )
+  const QString source = QgsApplication::sourceCache()->localFilePath( symbol->shapeProperty( QStringLiteral( "model" ) ).toString() );
+  if ( !source.isEmpty() )
   {
-    const QString source = QgsApplication::sourceCache()->localFilePath( symbol->shapeProperty( QStringLiteral( "model" ) ).toString() );
-    if ( !source.isEmpty() )
+    // build the default material
+    QgsMaterialContext materialContext;
+    materialContext.setIsSelected( are_selected );
+    materialContext.setSelectionColor( context.selectionColor() );
+    QgsMaterial *mat = symbol->materialSettings()->toMaterial( QgsMaterialSettingsRenderingTechnique::Triangles, materialContext );
+
+    const QUrl url = QUrl::fromLocalFile( source );
+
+    // get nodes
+    for ( const QVector3D &position : positions )
     {
       // build the entity
       Qt3DCore::QEntity *entity = new Qt3DCore::QEntity;
 
-      const QUrl url = QUrl::fromLocalFile( source );
       Qt3DRender::QMesh *mesh = new Qt3DRender::QMesh;
       mesh->setSource( url );
 
@@ -557,6 +579,10 @@ void QgsModelPoint3DSymbolHandler::addMeshEntities( const Qgs3DRenderContext &co
       // cppcheck-suppress memleak
     }
   }
+  else
+  {
+    QgsDebugMsgLevel( QStringLiteral( "File '%1' is not accessible!" ).arg( symbol->shapeProperty( QStringLiteral( "model" ) ).toString() ), 1 );
+  }
 }
 
 QgsGeoTransform *QgsModelPoint3DSymbolHandler::transform( QVector3D position, const QgsPoint3DSymbol *symbol, const QgsVector3D &chunkOrigin )
@@ -642,6 +668,11 @@ void QgsPoint3DBillboardSymbolHandler::finalize( Qt3DCore::QEntity *parent, cons
 
 void QgsPoint3DBillboardSymbolHandler::makeEntity( Qt3DCore::QEntity *parent, const Qgs3DRenderContext &context, PointData &out, bool selected )
 {
+  if ( out.positions.isEmpty() )
+  {
+    return; // nothing to show - no need to create the entity
+  }
+
   // Billboard Geometry
   QgsBillboardGeometry *billboardGeometry = new QgsBillboardGeometry();
   billboardGeometry->setPoints( out.positions );
