@@ -40,6 +40,11 @@ QString QgsUnionAlgorithm::groupId() const
   return QStringLiteral( "vectoroverlay" );
 }
 
+QStringList QgsUnionAlgorithm::tags() const
+{
+  return QObject::tr( "overlap,clip,union,not overlap" ).split( ',' );
+}
+
 QString QgsUnionAlgorithm::shortHelpString() const
 {
   return QObject::tr( "This algorithm checks overlaps between features within the Input layer and creates separate features for overlapping "
@@ -52,6 +57,12 @@ QString QgsUnionAlgorithm::shortHelpString() const
                         "for non-overlapping features, and attribute values from both layers for overlapping features." );
 }
 
+QString QgsUnionAlgorithm::shortDescription() const
+{
+  return QObject::tr( "Checks overlaps between features on the same layer or on two different layers "
+                      "and creates separate features for overlapping and non-overlapping parts." );
+}
+
 Qgis::ProcessingAlgorithmDocumentationFlags QgsUnionAlgorithm::documentationFlags() const
 {
   return Qgis::ProcessingAlgorithmDocumentationFlag::RegeneratesPrimaryKey;
