@@ -14,6 +14,7 @@
  ***************************************************************************/
 
 #include "qgsmaplayerlegend.h"
+#include "moc_qgsmaplayerlegend.cpp"
 #include "qgsiconutils.h"
 #include "qgsimagecache.h"
 #include "qgssettings.h"
@@ -212,7 +213,7 @@ void QgsMapLayerLegendUtils::setLegendNodeCustomSymbol( QgsLayerTreeLayer *nodeL
     nodeLayer->removeCustomProperty( "legend/custom-symbol-" + QString::number( originalIndex ) );
 }
 
-QgsSymbol *QgsMapLayerLegendUtils::legendNodeCustomSymbol( QgsLayerTreeLayer *nodeLayer, int originalIndex )
+std::unique_ptr< QgsSymbol > QgsMapLayerLegendUtils::legendNodeCustomSymbol( QgsLayerTreeLayer *nodeLayer, int originalIndex )
 {
   const QString symbolDef = nodeLayer->customProperty( "legend/custom-symbol-" + QString::number( originalIndex ) ).toString();
   if ( symbolDef.isEmpty() )
@@ -259,7 +260,7 @@ QgsColorRampLegendNodeSettings *QgsMapLayerLegendUtils::legendNodeColorRampSetti
 
   QgsColorRampLegendNodeSettings settings;
   settings.readXml( elem, rwContext );
-  return new QgsColorRampLegendNodeSettings( settings );
+  return new QgsColorRampLegendNodeSettings( std::move( settings ) );
 }
 
 void QgsMapLayerLegendUtils::setLegendNodeColumnBreak( QgsLayerTreeLayer *nodeLayer, int originalIndex, bool columnBreakBeforeNode )
@@ -291,7 +292,7 @@ void QgsMapLayerLegendUtils::applyLayerNodeProperties( QgsLayerTreeLayer *nodeLa
       const QgsLegendPatchShape shape = QgsMapLayerLegendUtils::legendNodePatchShape( nodeLayer, i );
       symbolNode->setPatchShape( shape );
 
-      symbolNode->setCustomSymbol( QgsMapLayerLegendUtils::legendNodeCustomSymbol( nodeLayer, i ) );
+      symbolNode->setCustomSymbol( QgsMapLayerLegendUtils::legendNodeCustomSymbol( nodeLayer, i ).release() );
     }
     else if ( QgsColorRampLegendNode *colorRampNode = dynamic_cast< QgsColorRampLegendNode * >( legendNode ) )
     {
