@@ -15,6 +15,7 @@
  ***************************************************************************/
 
 #include "qgsmaptoolmodifyannotation.h"
+#include "moc_qgsmaptoolmodifyannotation.cpp"
 #include "qgsrubberband.h"
 #include "qgsmapmouseevent.h"
 #include "qgsmapcanvas.h"
@@ -36,18 +37,20 @@
 class QgsAnnotationItemNodesSpatialIndex : public RTree<int, float, 2, float>
 {
   public:
-
     void insert( int index, const QgsRectangle &bounds )
     {
-      std::array< float, 4 > scaledBounds = scaleBounds( bounds );
-      this->Insert(
-      {
-        scaledBounds[0], scaledBounds[ 1]
-      },
-      {
+      std::array<float, 4> scaledBounds = scaleBounds( bounds );
+      const float aMin[2] {
+        scaledBounds[0], scaledBounds[1]
+      };
+      const float aMax[2] {
         scaledBounds[2], scaledBounds[3]
-      },
-      index );
+      };
+      this->Insert(
+        aMin,
+        aMax,
+        index
+      );
     }
 
     /**
@@ -58,15 +61,18 @@ class QgsAnnotationItemNodesSpatialIndex : public RTree<int, float, 2, float>
      */
     void remove( int index, const QgsRectangle &bounds )
     {
-      std::array< float, 4 > scaledBounds = scaleBounds( bounds );
-      this->Remove(
-      {
-        scaledBounds[0], scaledBounds[ 1]
-      },
-      {
+      std::array<float, 4> scaledBounds = scaleBounds( bounds );
+      const float aMin[2] {
+        scaledBounds[0], scaledBounds[1]
+      };
+      const float aMax[2] {
         scaledBounds[2], scaledBounds[3]
-      },
-      index );
+      };
+      this->Remove(
+        aMin,
+        aMax,
+        index
+      );
     }
 
     /**
@@ -74,29 +80,31 @@ class QgsAnnotationItemNodesSpatialIndex : public RTree<int, float, 2, float>
      *
      * The \a callback function will be called once for each matching data object encountered.
      */
-    bool intersects( const QgsRectangle &bounds, const std::function< bool( int index )> &callback ) const
+    bool intersects( const QgsRectangle &bounds, const std::function<bool( int index )> &callback ) const
     {
-      std::array< float, 4 > scaledBounds = scaleBounds( bounds );
-      this->Search(
-      {
-        scaledBounds[0], scaledBounds[ 1]
-      },
-      {
+      std::array<float, 4> scaledBounds = scaleBounds( bounds );
+      const float aMin[2] {
+        scaledBounds[0], scaledBounds[1]
+      };
+      const float aMax[2] {
         scaledBounds[2], scaledBounds[3]
-      },
-      callback );
+      };
+      this->Search(
+        aMin,
+        aMax,
+        callback
+      );
       return true;
     }
 
   private:
     std::array<float, 4> scaleBounds( const QgsRectangle &bounds ) const
     {
-      return
-      {
-        static_cast< float >( bounds.xMinimum() ),
-        static_cast< float >( bounds.yMinimum() ),
-        static_cast< float >( bounds.xMaximum() ),
-        static_cast< float >( bounds.yMaximum() )
+      return {
+        static_cast<float>( bounds.xMinimum() ),
+        static_cast<float>( bounds.yMinimum() ),
+        static_cast<float>( bounds.xMaximum() ),
+        static_cast<float>( bounds.yMaximum() )
       };
     }
 };
@@ -107,7 +115,6 @@ QgsMapToolModifyAnnotation::QgsMapToolModifyAnnotation( QgsMapCanvas *canvas, Qg
   : QgsMapToolAdvancedDigitizing( canvas, cadDockWidget )
   , mSnapIndicator( new QgsSnapIndicator( canvas ) )
 {
-
   connect( QgsMapToolModifyAnnotation::canvas(), &QgsMapCanvas::mapCanvasRefreshed, this, &QgsMapToolModifyAnnotation::onCanvasRefreshed );
 }
 
@@ -149,10 +156,8 @@ void QgsMapToolModifyAnnotation::cadCanvasMoveEvent( QgsMapMouseEvent *event )
       {
         const QgsVector delta = toLayerCoordinates( layer, event->mapPoint() ) - mMoveStartPointLayerCrs;
 
-        QgsAnnotationItemEditOperationTranslateItem operation( mSelectedItemId, delta.x(), delta.y(),
-            event->pixelPoint().x() - mMoveStartPointPixels.x(),
-            event->pixelPoint().y() - mMoveStartPointPixels.y() );
-        std::unique_ptr< QgsAnnotationItemEditOperationTransientResults > operationResults( item->transientEditResultsV2( &operation, context ) );
+        QgsAnnotationItemEditOperationTranslateItem operation( mSelectedItemId, delta.x(), delta.y(), event->pixelPoint().x() - mMoveStartPointPixels.x(), event->pixelPoint().y() - mMoveStartPointPixels.y() );
+        std::unique_ptr<QgsAnnotationItemEditOperationTransientResults> operationResults( item->transientEditResultsV2( &operation, context ) );
         if ( operationResults )
         {
           mTemporaryRubberBand.reset( new QgsRubberBand( mCanvas, operationResults->representativeGeometry().type() ) );
@@ -173,10 +178,8 @@ void QgsMapToolModifyAnnotation::cadCanvasMoveEvent( QgsMapMouseEvent *event )
       if ( QgsAnnotationItem *item = annotationItemFromId( mSelectedItemLayerId, mSelectedItemId ) )
       {
         const QgsPointXY endPointLayer = toLayerCoordinates( layer, event->mapPoint() );
-        QgsAnnotationItemEditOperationMoveNode operation( mSelectedItemId, mTargetNode.id(), QgsPoint( mTargetNode.point() ), QgsPoint( endPointLayer ),
-            event->pixelPoint().x() - mMoveStartPointPixels.x(),
-            event->pixelPoint().y() - mMoveStartPointPixels.y() );
-        std::unique_ptr< QgsAnnotationItemEditOperationTransientResults > operationResults( item->transientEditResultsV2( &operation, context ) );
+        QgsAnnotationItemEditOperationMoveNode operation( mSelectedItemId, mTargetNode.id(), QgsPoint( mTargetNode.point() ), QgsPoint( endPointLayer ), event->pixelPoint().x() - mMoveStartPointPixels.x(), event->pixelPoint().y() - mMoveStartPointPixels.y() );
+        std::unique_ptr<QgsAnnotationItemEditOperationTransientResults> operationResults( item->transientEditResultsV2( &operation, context ) );
         if ( operationResults )
         {
           mTemporaryRubberBand.reset( new QgsRubberBand( mCanvas, operationResults->representativeGeometry().type() ) );
@@ -223,9 +226,8 @@ void QgsMapToolModifyAnnotation::cadCanvasPressEvent( QgsMapMouseEvent *event )
           searchRect.grow( searchRadiusMU( canvas() ) );
 
           QgsAnnotationItemNode hoveredNode;
-          double currentNodeDistance = std::numeric_limits< double >::max();
-          mHoveredItemNodesSpatialIndex->intersects( searchRect, [&hoveredNode, &currentNodeDistance, &mapPoint, this]( int index )-> bool
-          {
+          double currentNodeDistance = std::numeric_limits<double>::max();
+          mHoveredItemNodesSpatialIndex->intersects( searchRect, [&hoveredNode, &currentNodeDistance, &mapPoint, this]( int index ) -> bool {
             const QgsAnnotationItemNode &thisNode = mHoveredItemNodes.at( index );
             const double nodeDistance = thisNode.point().sqrDist( mapPoint );
             if ( nodeDistance < currentNodeDistance )
@@ -296,9 +298,7 @@ void QgsMapToolModifyAnnotation::cadCanvasPressEvent( QgsMapMouseEvent *event )
         {
           const QgsVector delta = toLayerCoordinates( layer, event->mapPoint() ) - mMoveStartPointLayerCrs;
 
-          QgsAnnotationItemEditOperationTranslateItem operation( mSelectedItemId, delta.x(), delta.y(),
-              event->pixelPoint().x() - mMoveStartPointPixels.x(),
-              event->pixelPoint().y() - mMoveStartPointPixels.y() );
+          QgsAnnotationItemEditOperationTranslateItem operation( mSelectedItemId, delta.x(), delta.y(), event->pixelPoint().x() - mMoveStartPointPixels.x(), event->pixelPoint().y() - mMoveStartPointPixels.y() );
           switch ( layer->applyEditV2( &operation, context ) )
           {
             case Qgis::AnnotationItemEditOperationResult::Success:
@@ -333,9 +333,7 @@ void QgsMapToolModifyAnnotation::cadCanvasPressEvent( QgsMapMouseEvent *event )
         if ( layer )
         {
           const QgsPointXY endPointLayer = toLayerCoordinates( layer, event->mapPoint() );
-          QgsAnnotationItemEditOperationMoveNode operation( mSelectedItemId, mTargetNode.id(), QgsPoint( mTargetNode.point() ), QgsPoint( endPointLayer ),
-              event->pixelPoint().x() - mMoveStartPointPixels.x(),
-              event->pixelPoint().y() - mMoveStartPointPixels.y() );
+          QgsAnnotationItemEditOperationMoveNode operation( mSelectedItemId, mTargetNode.id(), QgsPoint( mTargetNode.point() ), QgsPoint( endPointLayer ), event->pixelPoint().x() - mMoveStartPointPixels.x(), event->pixelPoint().y() - mMoveStartPointPixels.y() );
           switch ( layer->applyEditV2( &operation, context ) )
           {
             case Qgis::AnnotationItemEditOperationResult::Success:
@@ -434,7 +432,6 @@ void QgsMapToolModifyAnnotation::keyPressEvent( QKeyEvent *event )
     {
       if ( event->key() == Qt::Key_Backspace || event->key() == Qt::Key_Delete )
       {
-
         if ( !layer || mSelectedItemId.isEmpty() )
           return;
 
@@ -543,9 +540,8 @@ void QgsMapToolModifyAnnotation::onCanvasRefreshed()
     }
 
     const QList<QgsRenderedItemDetails *> items = renderedItemResults->renderedItems();
-    auto it = std::find_if( items.begin(), items.end(), [this]( const QgsRenderedItemDetails * item )
-    {
-      if ( const QgsRenderedAnnotationItemDetails *annotationItem = dynamic_cast< const QgsRenderedAnnotationItemDetails *>( item ) )
+    auto it = std::find_if( items.begin(), items.end(), [this]( const QgsRenderedItemDetails *item ) {
+      if ( const QgsRenderedAnnotationItemDetails *annotationItem = dynamic_cast<const QgsRenderedAnnotationItemDetails *>( item ) )
       {
         if ( annotationItem->itemId() == mSelectedItemId && annotationItem->layerId() == mSelectedItemLayerId )
           return true;
@@ -556,7 +552,7 @@ void QgsMapToolModifyAnnotation::onCanvasRefreshed()
     {
       const QgsRectangle itemBounds = ( *it )->boundingBox();
 
-      setHoveredItem( dynamic_cast< const QgsRenderedAnnotationItemDetails *>( *it ), itemBounds );
+      setHoveredItem( dynamic_cast<const QgsRenderedAnnotationItemDetails *>( *it ), itemBounds );
       if ( !mSelectedRubberBand )
         createSelectedItemBand();
 
@@ -607,7 +603,7 @@ void QgsMapToolModifyAnnotation::setHoveredItem( const QgsRenderedAnnotationItem
   context.setCurrentItemBounds( toLayerCoordinates( layer, itemMapBounds ) );
   context.setRenderContext( QgsRenderContext::fromMapSettings( canvas()->mapSettings() ) );
 
-  const QList< QgsAnnotationItemNode > itemNodes = annotationItem->nodesV2( context );
+  const QList<QgsAnnotationItemNode> itemNodes = annotationItem->nodesV2( context );
   QgsRubberBand *vertexNodeBand = new QgsRubberBand( mCanvas, Qgis::GeometryType::Point );
 
   vertexNodeBand->setIcon( QgsRubberBand::ICON_BOX );
@@ -623,7 +619,7 @@ void QgsMapToolModifyAnnotation::setHoveredItem( const QgsRenderedAnnotationItem
   calloutNodeBand->setIconSize( scaleFactor * 5 );
 
   // store item nodes in a spatial index for quick searching
-  mHoveredItemNodesSpatialIndex = std::make_unique< QgsAnnotationItemNodesSpatialIndex >();
+  mHoveredItemNodesSpatialIndex = std::make_unique<QgsAnnotationItemNodesSpatialIndex>();
   int index = 0;
   mHoveredItemNodes.clear();
   mHoveredItemNodes.reserve( itemNodes.size() );
@@ -650,8 +646,7 @@ void QgsMapToolModifyAnnotation::setHoveredItem( const QgsRenderedAnnotationItem
         break;
     }
 
-    mHoveredItemNodesSpatialIndex->insert( index, QgsRectangle( nodeMapPoint.x(), nodeMapPoint.y(),
-                                           nodeMapPoint.x(), nodeMapPoint.y() ) );
+    mHoveredItemNodesSpatialIndex->insert( index, QgsRectangle( nodeMapPoint.x(), nodeMapPoint.y(), nodeMapPoint.x(), nodeMapPoint.y() ) );
 
     QgsAnnotationItemNode transformedNode = node;
     transformedNode.setPoint( nodeMapPoint );
@@ -719,8 +714,8 @@ QSizeF QgsMapToolModifyAnnotation::deltaForKeyEvent( QgsAnnotationLayer *layer,
 const QgsRenderedAnnotationItemDetails *QgsMapToolModifyAnnotation::findClosestItemToPoint( const QgsPointXY &mapPoint, const QList<const QgsRenderedAnnotationItemDetails *> &items, QgsRectangle &bounds )
 {
   const QgsRenderedAnnotationItemDetails *closestItem = nullptr;
-  double closestItemDistance = std::numeric_limits< double >::max();
-  double closestItemArea = std::numeric_limits< double >::max();
+  double closestItemDistance = std::numeric_limits<double>::max();
+  double closestItemArea = std::numeric_limits<double>::max();
 
   for ( const QgsRenderedAnnotationItemDetails *item : items )
   {
@@ -743,7 +738,7 @@ const QgsRenderedAnnotationItemDetails *QgsMapToolModifyAnnotation::findClosestI
 
 QgsAnnotationLayer *QgsMapToolModifyAnnotation::annotationLayerFromId( const QString &layerId )
 {
-  QgsAnnotationLayer *layer = qobject_cast< QgsAnnotationLayer * >( QgsProject::instance()->mapLayer( layerId ) );
+  QgsAnnotationLayer *layer = qobject_cast<QgsAnnotationLayer *>( QgsProject::instance()->mapLayer( layerId ) );
   if ( !layer && layerId == QgsProject::instance()->mainAnnotationLayer()->id() )
     layer = QgsProject::instance()->mainAnnotationLayer();
   return layer;
@@ -792,9 +787,8 @@ void QgsMapToolModifyAnnotation::setHoveredItemFromPoint( const QgsPointXY &mapP
   QgsAnnotationItemNode hoveredNode;
   if ( closestItem->itemId() == mSelectedItemId && closestItem->layerId() == mSelectedItemLayerId )
   {
-    double currentNodeDistance = std::numeric_limits< double >::max();
-    mHoveredItemNodesSpatialIndex->intersects( searchRect, [&hoveredNode, &currentNodeDistance, &mapPoint, this]( int index )-> bool
-    {
+    double currentNodeDistance = std::numeric_limits<double>::max();
+    mHoveredItemNodesSpatialIndex->intersects( searchRect, [&hoveredNode, &currentNodeDistance, &mapPoint, this]( int index ) -> bool {
       if ( index >= mHoveredItemNodes.size() )
         return false;
 
@@ -886,4 +880,3 @@ void QgsMapToolModifyAnnotation::createSelectedItemBand()
   mSelectedRubberBand->setSecondaryStrokeColor( QColor( 255, 255, 255, 100 ) );
   mSelectedRubberBand->setColor( QColor( 50, 50, 50, 200 ) );
 }
-
